Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(780)

Unified Diff: mandoline/services/core_services/application_delegate_factory.h

Issue 1675083002: Rename ApplicationDelegate to ShellClient (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@delegate
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: mandoline/services/core_services/application_delegate_factory.h
diff --git a/mandoline/services/core_services/application_delegate_factory.h b/mandoline/services/core_services/application_delegate_factory.h
index 537d9f9815f831adcb4f594fa7b40f5a1d87b53d..60adff063a65e844ab539fdc664b7191913ca294 100644
--- a/mandoline/services/core_services/application_delegate_factory.h
+++ b/mandoline/services/core_services/application_delegate_factory.h
@@ -10,20 +10,20 @@
#include "base/memory/scoped_ptr.h"
namespace mojo {
-class ApplicationDelegate;
+class ShellClient;
}
namespace core_services {
-// This is always called to create a platform specific ApplicationDelegate.
-scoped_ptr<mojo::ApplicationDelegate> CreatePlatformSpecificApplicationDelegate(
+// This is always called to create a platform specific ShellClient.
+scoped_ptr<mojo::ShellClient> CreatePlatformSpecificApplicationDelegate(
const std::string& url);
// The following are conditionally called. You do not need to call these from
// CreatePlatformSpecificApplicationDelegate(), they are called (if appropriate)
// before CreatePlatformSpecificApplicationDelegate().
#if !defined(OS_ANDROID)
-scoped_ptr<mojo::ApplicationDelegate> CreateApplicationDelegateNotAndroid(
+scoped_ptr<mojo::ShellClient> CreateApplicationDelegateNotAndroid(
const std::string& url);
#endif

Powered by Google App Engine
This is Rietveld 408576698